import { _decorator, Component, Node, debug, log, Label, error } from "cc";
import CrazySDK from "./CrazySDK";
const { ccclass, property } = _decorator;

/**
 * You can find the documentation here https://docs.crazygames.com/sdk/cocos
 */

@ccclass("CrazySDKDemo")
export class CrazySDKDemo extends Component {
  @property({ type: Label })
  sdkStatus: Label;

  @property({ type: Label })
  adblockUsageLabel: Label;

  @property({ type: Label })
  inviteLinkLabel: Label;

  @property({ type: Label })
  userLabel: Label;

  onLoad() {
    // const listener = (user) => {
    //   debug("User auth listener", user);
    // };
    // CrazySDK.user.addAuthListener(listener);
    // CrazySDK.user.removeAuthListener(listener); // remove listener example

    CrazySDK.getEnvironment().then((environment) => {
      this.sdkStatus.string = `Environment: ${environment}, SDK is ${CrazySDK.isEnabled ? "enabled" : "disabled"}`;
    });
  }

  //#region Ad module

  showRewardedVideo() {
    CrazySDK.ad.requestAd("rewarded", {
      adError: (errorMessage, errorData) => {
        log("Rewarded video error", errorMessage, errorData);
      },
      adStarted: () => {
        log("Rewarded video started");
      },
      adFinished: () => {
        log("Rewarded video finished");
      },
    });
  }

  showAdBreakVideo() {
    CrazySDK.ad.requestAd("midgame", {
      adError: (errorMessage, errorData) => {
        log("Ad break video error", errorMessage, errorData);
      },
      adStarted: () => {
        log("Ad break video started");
      },
      adFinished: () => {
        log("Ad break video finished");
      },
    });
  }

  //#endregion

  //#region Game module

  async checkAdblockUsage() {
    try {
      const adblockUsage = await CrazySDK.ad.hasAdblock(); // you can also pass a callback object if you don't have the possibility to use promises
      this.adblockUsageLabel.string = `Adblock: ${adblockUsage ? "on" : "off"}`;
    } catch (e) {
      this.adblockUsageLabel.string = "Adblock check failed";
      error("Adblock check failed", e);
    }
  }

  gameplayStart() {
    CrazySDK.game.gameplayStart();
  }

  gameplayStop() {
    CrazySDK.game.gameplayStop();
  }

  sdkGameLoadingStart() {
    CrazySDK.game.sdkGameLoadingStart();
  }

  sdkGameLoadingStop() {
    CrazySDK.game.sdkGameLoadingStop();
  }

  happytime() {
    CrazySDK.game.happytime();
  }

  async inviteLink() {
    const inviteLink = await CrazySDK.game.inviteLink({ roomId: "123" }); // you can also pass a callback object if you don't have the possibility to use promises
    this.inviteLinkLabel.string = inviteLink;
  }

  //#endregion
}
